@@ -94,6 +94,22 @@ def configure_parser(parser, version):
             "env", type=argparse.FileType("r"), help="environment file"
         )
 
+    if version >= (2022, 1):
+        # "env-dut"
+        workers_env_dut = sub.add_parser("env-dut", help="worker environment")
+        env_dut_sub = workers_env_dut.add_subparsers(
+            dest="sub_sub_sub_command", help="Sub commands"
+        )
+        env_dut_sub.required = True
+        env_dut_get = env_dut_sub.add_parser("get", help="get the dut environment")
+        env_dut_get.add_argument("name", type=str, help="worker name")
+
+        env_dut_set = env_dut_sub.add_parser("set", help="set the dut environment")
+        env_dut_set.add_argument("name", type=str, help="worker name")
+        env_dut_set.add_argument(
+            "env", type=argparse.FileType("r"), help="environment file"
+        )
+
     # "list"
     workers_list = sub.add_parser("list", help="list workers")
     out_format = workers_list.add_mutually_exclusive_group()
@@ -236,6 +252,19 @@ def handle_env(proxy, options, _):
     return 0
 
 
+def handle_env_dut(proxy, options, _):
+    if options.sub_sub_sub_command == "get":
+        env = proxy.scheduler.workers.get_env_dut(options.name)
+        print(str(env).rstrip("\n"))
+    else:
+        env = options.env.read()
+        ret = proxy.scheduler.workers.set_env_dut(options.name, env)
+        if not ret:
+            print("Unable to store worker environment")
+            return 1
+    return 0
+
+
 def handle_list(proxy, options, _):
     workers = proxy.scheduler.workers.list()
     if options.output_format == "json":
@@ -333,6 +362,7 @@ def handle(proxy, options, config):
         "config": handle_config,
         "certificate": handle_certificate,
         "env": handle_env,
+        "env-dut": handle_env_dut,
         "list": handle_list,
         "maintenance": handle_maintenance,
         "show": handle_show,
