@@ -47,7 +47,7 @@ class RecordingProxyFactory(object):
 
 @pytest.fixture
 def setup(monkeypatch, tmpdir):
-    monkeypatch.setenv("XDG_CONFIG_HOME", tmpdir)
+    monkeypatch.setenv("XDG_CONFIG_HOME", str(tmpdir))
     with (tmpdir / "lavacli.yaml").open("w") as f_conf:
         f_conf.write(yaml.dump({"default": {"uri": "https://lava.example.com/RPC2"}}))
     monkeypatch.setattr(xmlrpc.client, "ServerProxy", RecordingProxyFactory(None))
